==> ocamlformat_0.26.2.orig.tar.bz2: ocamlformat-0.26.2/test/passing/tests/break_string_literals.ml <==
let () =
  if true then (* Shrinking the margin a bit *)
    Format.printf
      "@[<v 2>@{<warning>@{<title>Warning@}@}@,@,\
      \        These are @{<warning>NOT@} the Droids you are looking for!@,\
       @,\
      \        Some more text. Just more letters and words.@,\
      \        All this text is left-aligned because it's part of the UI.@,\
      \        It'll be easier for the user to read this message.@]@\n@."

let fooooooo =
  "@\n\n\
    \               [Perf Profiler Log] Function: '%s'  @\n\
    \               count trace id = %i @\n\
    \               sum inclusive cpu time = %f@\n\
    \               avg inclusive time = %f @\n\
    \               sum exclusive cpu time = %f @\n\
    \               avg exclusive_time = %f  @\n\
    \               inclusive p90 = %f  @\n\
    \               exclusive p90 = %f @\n\
    \               inclusive p50 = %f  @\n\
    \               exclusive p50 = %f @\n\
    \               inclusive p25 = %f  @\n\
    \               exclusive p25 = %f @\n"

let foooo =
  Printf.sprintf
    "%s\nUsage: infer %s [options]\nSee `infer%s --help` for more information."

let pp_sep fmt () = F.fprintf fmt ", @,\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n@\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n@;@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@,@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@\n\n"

let fooooooooo = Fooooo "[%a]\n"

let fooooooooo = Fooooo "[%a]@\n"

let fooooooooo = Fooooo "[%a]\n@\n"

let fooooooooo = Fooooo "[%a]@\n\n"

let fooo = Fooo "@\nFooooo: `%s`\n"

let fooooooooooo = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."

let fooooooooooo = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.@;Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.@;Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.@;Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."

let _ = "abc@,def\n\nghi"
let _ = "abc@,def\n\n ghi"
let _ = "abc@,def\n\n"
let _ = "abc@,def@\n\n"

==> ocamlformat_0.27.0.orig.tar.bz2: ocamlformat-0.27.0/test/passing/tests/break_string_literals.ml <==
let () =
  if true then (* Shrinking the margin a bit *)
    Format.printf
      "@[<v 2>@{<warning>@{<title>Warning@}@}@,@,\
      \        These are @{<warning>NOT@} the Droids you are looking for!@,\
       @,\
      \        Some more text. Just more letters and words.@,\
      \        All this text is left-aligned because it's part of the UI.@,\
      \        It'll be easier for the user to read this message.@]@\n@."

let fooooooo =
  "@\n\n\
    \               [Perf Profiler Log] Function: '%s'  @\n\
    \               count trace id = %i @\n\
    \               sum inclusive cpu time = %f@\n\
    \               avg inclusive time = %f @\n\
    \               sum exclusive cpu time = %f @\n\
    \               avg exclusive_time = %f  @\n\
    \               inclusive p90 = %f  @\n\
    \               exclusive p90 = %f @\n\
    \               inclusive p50 = %f  @\n\
    \               exclusive p50 = %f @\n\
    \               inclusive p25 = %f  @\n\
    \               exclusive p25 = %f @\n"

let foooo =
  Printf.sprintf
    "%s\nUsage: infer %s [options]\nSee `infer%s --help` for more information."

let pp_sep fmt () = F.fprintf fmt ", @,\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,@\n@\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@\n\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n@;@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@,@\n"

let pp_sep fmt () = F.fprintf fmt ", @,\n@\n\n@\n\n"

let fooooooooo = Fooooo "[%a]\n"

let fooooooooo = Fooooo "[%a]@\n"

let fooooooooo = Fooooo "[%a]\n@\n"

let fooooooooo = Fooooo "[%a]@\n\n"

let fooo = Fooo "@\nFooooo: `%s`\n"

let fooooooooooo = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."

let fooooooooooo = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.@;Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.@;Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.@;Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."

let _ = "abc@,def\n\nghi"
let _ = "abc@,def\n\n ghi"
let _ = "abc@,def\n\n"
let _ = "abc@,def@\n\n"

let _ =
  Pp.textf
    "Failed to parse environment variable: %s=%s\n\
     Permitted values: if-exists always never\n\
     Default: %s"
    var v (to_string default)

let _ =
  Pp.textf
    "Failed to parse environment variable: %s=%s \
     Permitted values: if-exists always never \
     Default: %s"
    var v (to_string default)
